==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/de.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Der angegebene Operator ist ungültig",
    "The given regular expression is invalid" : "Der angegebene Reguläre Ausdruck ist ungültig",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Tag-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist ungültig",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist ungültig für IPv4",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist ungültig für IPv6",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungütlig",
    "The given start time is invalid" : "Die angegebene Anfangszeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "File" : "Datei",
    "File created" : "Datei erstellt",
    "File updated" : "Datei aktualisiert",
    "File renamed" : "Datei umbenannt",
    "File deleted" : "Datei gelöscht",
    "File accessed" : "Auf Datei zugegriffen",
    "File copied" : "Datei kopiert",
    "Tag assigned" : "Schlagwort zugewiesen",
    "Operation #%s does not exist" : "Operation #%s existert nicht",
    "Entity %s does not exist" : "Entität %s existiert nicht",
    "Entity %s is invalid" : "Entität %s ist ungültig",
    "No events are chosen." : "Kein Ereignis ausgewählt.",
    "Entity %s has no event %s" : "Die Entität %s hat kein Ereignis %s",
    "Operation %s does not exist" : "Operation %s existert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Workflows" : "Arbeitsabläufe",
    "Nextcloud workflow engine" : "Nxtcloud Arbeitsablauf-Engine",
    "Select a filter" : "Filter auswählen",
    "Select a comparator" : "Wähle einen Komparator",
    "Select a file type" : "Dateityp auswählen",
    "e.g. httpd/unix-directory" : "z.B. httpd/unix-directory",
    "Images" : "Bilder",
    "Office documents" : "Office Dokumente",
    "PDF documents" : "PDF-Dokumente",
    "Custom mimetype" : "Benutzerdefinierter Mime-Typ",
    "Select a tag" : "Schlagwort auswählen",
    "No results" : "Keine Ergebnisse",
    "%s (invisible)" : "%s(unsichtbar)",
    "%s (restricted)" : "%s (eingeschränkt)",
    "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
    "Select a request URL" : "Wählen Sie eine Anforderungs-URL aus",
    "Predefined URLs" : "Vordefinierte URLs",
    "Files WebDAV" : "WebDAV für Dateien",
    "Others" : "Andere",
    "Custom URL" : "Benutzerdefinierte URL",
    "Select a user agent" : "User-Agenten auswählen",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Custom user agent" : "Benutzerdefinierter User-Agent",
    "When" : "Wenn",
    "and" : "und",
    "Cancel" : "Abbrechen",
    "Delete" : "Löschen",
    "The configuration is invalid" : "Die Konfiguration ist ungültig",
    "Show less" : "Weniger anzeigen",
    "Show more" : "Mehr anzeigen",
    "File name" : "Dateiname",
    "is" : "ist",
    "is not" : "ist nicht",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "File MIME type" : "Datei MIME-Typ",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "Request remote address" : "IP Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "File system tag" : "Kollaborativer Tag an Datei",
    "is tagged with" : "ist getaggt mit",
    "is not tagged with" : "ist nicht getaggt mit",
    "Request URL" : "Anfrage-URL",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Request user agent" : "User-Agent",
    "User group membership" : "Benutzergruppen-Mitgliedschaft",
    "is member of" : "ist Mitglied von",
    "is not member of" : "ist kein Mitglied von",
    "Short rule description" : "Kurze Regelbeschreibung",
    "Add rule" : "Regel hinzufügen",
    "Reset" : "Zurücksetzen",
    "Save" : "Speichern",
    "Saving…" : "Speichern…",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht empfangen werden",
    "Saved" : "Gespeichert",
    "Saving failed:" : "Speichern fehlgeschlagen:",
    "Add rule group" : "Regelgruppe hinzufügen",
    "Example: {placeholder}" : "Beispiel: {placeholder}",
    "Select tag…" : "Wähle einen Tag…",
    "Start" : "Start",
    "End" : "Ende",
    "Select timezone…" : "Wähle eine Zeitzone…",
    "Sync clients" : "Sync-Clients",
    "Workflow" : "Arbeitsablauf",
    "Files workflow engine" : "Datei-Arbeitsablauf-Engine",
    "Open documentation" : "Dokumentation öffnen",
    "Loading…" : "Laden…",
    "Tag management" : "Schlagwortverwaltung"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/de.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Der angegebene Operator ist ungültig",
    "The given regular expression is invalid" : "Der angegebene Reguläre Ausdruck ist ungültig",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Tag-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist ungültig",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist ungültig für IPv4",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist ungültig für IPv6",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungütlig",
    "The given start time is invalid" : "Die angegebene Anfangszeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "File" : "Datei",
    "File created" : "Datei erstellt",
    "File updated" : "Datei aktualisiert",
    "File renamed" : "Datei umbenannt",
    "File deleted" : "Datei gelöscht",
    "File accessed" : "Auf Datei zugegriffen",
    "File copied" : "Datei kopiert",
    "Tag assigned" : "Schlagwort zugewiesen",
    "Someone" : "Irgendjemand",
    "%s created %s" : "%s hat %s erstellt",
    "%s modified %s" : "%s hat %s geändert",
    "%s deleted %s" : "%s hat %s gelöscht",
    "%s accessed %s" : "%s hat auf %s zugegriffen ",
    "%s renamed %s" : "%s hat %s umbenannt",
    "%s copied %s" : "%s hat %s kopiert",
    "%s assigned %s to %s" : "%s hat %s zugewiesen an %s",
    "Operation #%s does not exist" : "Operation #%s existert nicht",
    "Entity %s does not exist" : "Entität %s existiert nicht",
    "Entity %s is invalid" : "Entität %s ist ungültig",
    "No events are chosen." : "Kein Ereignis ausgewählt.",
    "Entity %s has no event %s" : "Die Entität %s hat kein Ereignis %s",
    "Operation %s does not exist" : "Operation %s existert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "At least one check needs to be provided" : "Mindestens ein Test muss bereitgestellt werden",
    "Invalid check provided" : "Ungültiger Test bereitgestellt",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check %s is not allowed with this entity" : "Die Prüfung %s ist mit dieser Entität unzulässig",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Flow" : "Ablauf",
    "Nextcloud workflow engine" : "Nextcloud Arbeitsablauf-Engine",
    "Select a filter" : "Filter auswählen",
    "Select a comparator" : "Wähle einen Komparator",
    "Select a file type" : "Dateityp auswählen",
    "e.g. httpd/unix-directory" : "z.B. httpd/unix-directory",
    "Images" : "Bilder",
    "Office documents" : "Office Dokumente",
    "PDF documents" : "PDF-Dokumente",
    "Custom mimetype" : "Benutzerdefinierter Mime-Typ",
    "Select a tag" : "Schlagwort auswählen",
    "No results" : "Keine Ergebnisse",
    "%s (invisible)" : "%s(unsichtbar)",
    "%s (restricted)" : "%s (eingeschränkt)",
    "Please enter a valid time span" : "Bitte einen gültigen Zeitraum angeben",
    "Select a request URL" : "Wählen Sie eine Anforderungs-URL aus",
    "Predefined URLs" : "Vordefinierte URLs",
    "Files WebDAV" : "WebDAV für Dateien",
    "Others" : "Andere",
    "Custom URL" : "Benutzerdefinierte URL",
    "Select a user agent" : "User-Agenten auswählen",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "Custom user agent" : "Benutzerdefinierter User-Agent",
    "At least one event must be selected" : "Mindestens ein Ereignis muss ausgewählt werden",
    "Add new flow" : "Neuen Ablauf hinzufügen",
    "When" : "Wenn",
    "and" : "und",
    "Cancel" : "Abbrechen",
    "Delete" : "Löschen",
    "The configuration is invalid" : "Die Konfiguration ist ungültig",
    "Active" : "Aktiv",
    "Save" : "Speichern",
    "Available flows" : "Verfügbare Abläufe",
    "For details on how to write your own flow, check out the development documentation." : "Informationen wie eigene Abläufe erstellt werden, findest Du in der Entwickler-Dokumentation.",
    "More flows" : "Weitere Abläufe",
    "Browse the app store" : "Appstore durchsuchen",
    "Show less" : "Weniger anzeigen",
    "Show more" : "Mehr anzeigen",
    "Configured flows" : "Konfigurierte Abläufe",
    "Your flows" : "Deine Abläufe",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "is" : "ist",
    "is not" : "ist nicht",
    "File name" : "Dateiname",
    "File MIME type" : "Datei MIME-Typ",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "Request remote address" : "IP Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "File system tag" : "Kollaborativer Tag an Datei",
    "is tagged with" : "ist getaggt mit",
    "is not tagged with" : "ist nicht getaggt mit",
    "Request URL" : "Anfrage-URL",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Request user agent" : "User-Agent",
    "User group membership" : "Benutzergruppen-Mitgliedschaft",
    "is member of" : "ist Mitglied von",
    "is not member of" : "ist kein Mitglied von",
    "Short rule description" : "Kurze Regelbeschreibung",
    "Add rule" : "Regel hinzufügen",
    "Reset" : "Zurücksetzen",
    "Saving…" : "Speichern…",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht empfangen werden",
    "Saved" : "Gespeichert",
    "Saving failed:" : "Speichern fehlgeschlagen:",
    "Add rule group" : "Regelgruppe hinzufügen",
    "Example: {placeholder}" : "Beispiel: {placeholder}",
    "Select tag…" : "Wähle einen Tag…",
    "Start" : "Start",
    "End" : "Ende",
    "Select timezone…" : "Wähle eine Zeitzone…",
    "Sync clients" : "Sync-Clients",
    "Workflow" : "Arbeitsablauf",
    "Files workflow engine" : "Datei-Arbeitsablauf-Engine",
    "Open documentation" : "Dokumentation öffnen",
    "Loading…" : "Laden…",
    "Tag management" : "Schlagwortverwaltung"
},
"nplurals=2; plural=(n != 1);");
